@@ -542,8 +542,8 @@ class FiniteAutomaton():
             largest_cell=max(largest_cell,len(",".join(q_f)))
         largest_cell+=2
         if not order_Q:
-            order_Q=list(self.q)
-        if not order_a:
+            order_Q=list(self.Q)
+        if not order_sigma:
             order_sigma=list(self.sigma)
         with open(filename,'w') as f:
             print(" "*(largest_q+2),end="",file=f)
